"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class AssessmentsApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        {
                "count": 1,
                "next": null,
                "previous": null,
                "results": [ { ... } ],
                "risk_matrix_rollup": [ ... ],
            }

        :param dict params: asset: string
        asset__asset_path_cache__path: string
        asset__descendants: string
        asset__id: string
        asset__type__in: string
        asset_path__endswith: string
        asset_path__icontains: string
        asset_path__startswith: string
        limit: integer
        offset: integer
        ordering: string
        risk_score__cof: string
        risk_score__display: string
        risk_score__pof: string
        status__in: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/AssessmentList'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_assessments_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/assessments/",
            params=params,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific Assessment
        :params id Assessment ID

        :returns: $ref: '#/components/schemas/AssessmentDetail'

        https://docs.huvrdata.app/reference/api_assessments_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/assessments/{id}/",
            **kwargs,
        )

    def revision(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/schemas/AssessmentDetail'

        :returns: $ref: '#/components/schemas/AssessmentDetail'

        https://docs.huvrdata.app/reference/api_assessments_revision
        """
        return self.client.request_json(
            method="post",
            path=f"/api/assessments/{id}/revision/",
            json=json,
            **kwargs,
        )



import requests
import json
from typing import Union, List, Dict

# !! be sure to keep this up to date after regenerating !!

from .api.assessment_types import AssessmentTypesApiModule
from .api.assessments import AssessmentsApiModule
from .api.asset_types import AssetTypesApiModule
from .api.assets import AssetsApiModule
from .api.auth import AuthApiModule
from .api.checklist_result_lines import ChecklistResultLinesApiModule
from .api.checklist_tasks import ChecklistTasksApiModule
from .api.checklist_templates_fillable import ChecklistTemplatesFillableApiModule
from .api.checklist_templates import ChecklistTemplatesApiModule
from .api.checklists import ChecklistsApiModule
from .api.cmls import CmlsApiModule
from .api.companies import CompaniesApiModule
from .api.crews import CrewsApiModule
from .api.defect_profiles import DefectProfilesApiModule
from .api.defects import DefectsApiModule
from .api.heat_data import HeatDataApiModule
from .api.inspection_media_overlays import InspectionMediaOverlaysApiModule
from .api.inspection_media import InspectionMediaApiModule
from .api.libraries import LibrariesApiModule
from .api.library_media import LibraryMediaApiModule
from .api.location_layer_profiles import LocationLayerProfilesApiModule
from .api.measurements import MeasurementsApiModule
from .api.observations_summary import ObservationsSummaryApiModule
from .api.pages import PagesApiModule
from .api.project_types import ProjectTypesApiModule
from .api.projects import ProjectsApiModule
from .api.recommended_work_plans import RecommendedWorkPlansApiModule
from .api.reservations import ReservationsApiModule
from .api.schedules import SchedulesApiModule
from .api.users import UsersApiModule

from .exceptions import (
    HuvrApiError,
    HuvrApiAuthError,
    HuvrJSONResponseError,
    HuvrApiRequestError,
)


class HuvrClient:
    """
    REST API for HUVR.

    See full REST API documentation at https://docs.huvrdata.com
    """

    def __init__(
        self,
        base_url: str,
        verbose: bool = False,
    ):
        """
        Initialize the client.

        :param base_url: The base URL for the HUVR API. ex: https://demo.huvrdata.com
        :param verbose: print debug to stdout.
        """
        self.base_url = base_url
        # remove trailing slash if present
        if self.base_url.endswith("/"):
            self.base_url = self.base_url[:-1]

        self.verbose = verbose
        self.session = requests.Session()

        # modules
        #
        self.assessment_types = AssessmentTypesApiModule(self)
        self.assessments = AssessmentsApiModule(self)
        self.asset_types = AssetTypesApiModule(self)
        self.assets = AssetsApiModule(self)
        self.auth = AuthApiModule(self)
        self.checklist_result_lines = ChecklistResultLinesApiModule(self)
        self.checklist_tasks = ChecklistTasksApiModule(self)
        self.checklist_templates_fillable = ChecklistTemplatesFillableApiModule(self)
        self.checklist_templates = ChecklistTemplatesApiModule(self)
        self.checklists = ChecklistsApiModule(self)
        self.cmls = CmlsApiModule(self)
        self.companies = CompaniesApiModule(self)
        self.crews = CrewsApiModule(self)
        self.defect_profiles = DefectProfilesApiModule(self)
        self.defects = DefectsApiModule(self)
        self.heat_data = HeatDataApiModule(self)
        self.inspection_media_overlays = InspectionMediaOverlaysApiModule(self)
        self.inspection_media = InspectionMediaApiModule(self)
        self.libraries = LibrariesApiModule(self)
        self.library_media = LibraryMediaApiModule(self)
        self.location_layer_profiles = LocationLayerProfilesApiModule(self)
        self.measurements = MeasurementsApiModule(self)
        self.observations_summary = ObservationsSummaryApiModule(self)
        self.pages = PagesApiModule(self)
        self.project_types = ProjectTypesApiModule(self)
        self.projects = ProjectsApiModule(self)
        self.recommended_work_plans = RecommendedWorkPlansApiModule(self)
        self.reservations = ReservationsApiModule(self)
        self.schedules = SchedulesApiModule(self)
        self.users = UsersApiModule(self)

    def request_json(
        self, method: str, path: str, **kwargs
    ) -> "Union[requests.Response, List, Dict]":
        """
        Make a JSON request to the HUVR API.

        :param method: The HTTP method to use.
        :param path: The path to the endpoint.
        :param kwargs: Additional keyword arguments to pass to the request.
        """
        headers = {
            "Content-Type": "application/json",
            "Accept": "application/json",
            **kwargs.pop("headers", {}),
        }

        response = self.request(method, path, headers=headers, **kwargs)

        # check for errors
        try:
            response.raise_for_status()
        except requests.HTTPError as e:
            if response.status_code > 500:
                raise HuvrApiError(
                    f"Server Error: {response.content}", response=response
                ) from e
            elif response.status_code == 401:
                raise HuvrApiAuthError(
                    f"Authentication Error: {response.content}", response=response
                ) from e
            elif response.status_code > 400:
                raise HuvrApiRequestError(
                    f"Request Error: {response.content}", response=response
                ) from e
            else:
                raise HuvrApiError(
                    f"Unknown Error: {response.content}", response=response
                ) from e

        # cast to json
        try:
            data = response.json()
        except json.JSONDecodeError as e:
            raise HuvrJSONResponseError(
                f"Invalid JSON Response (hint, use `request_raw`` if json not expected): {response.content}",
                response=response,
            ) from e

        return data

    def request(self, method: str, path: str, **kwargs) -> "requests.Response":
        """
        Make a request to the HUVR API.

        hint - use `request` instead of this method, unless you expect a non-json response.

        :param method: The HTTP method to use.
        :param path: The path to the endpoint.
        :param kwargs: Additional keyword arguments to pass to the request.
        """

        url = self.base_url + path

        if self.verbose:
            print(
                "HUVR HTTP REQUEST: {} {} {}".format(
                    method,
                    url,
                    {
                        **kwargs,
                    },
                )
            )

        return self.session.request(
            method,
            url,
            **kwargs,
        )

    def authenticate(self, client_id: str, client_secret: str):
        """
        Authenticate with the HUVR API.

        The access token is good for 60 minutes.  Then must re-authenticate.

        https://docs.huvrdata.app/docs/authentication
        """
        data = self.auth.obtain_access_token_create(
            json={
                "client_id": client_id,
                "client_secret": client_secret,
            }
        )
        self.session.headers["Authorization"] = f"Token {data['access_token']}"


def get_huvr_client(
    base_url: str, client_id: str = None, client_secret: str = None
) -> "HuvrClient":
    """
    Get an authenticated HUVR client.

    :param base_url: The base URL for the HUVR API. ex: https://demo.huvrdata.com
    :param client_id: The client ID for the HUVR API.
        optional - if passed will authenticate the client.
    :param client_secret: The client secret for the HUVR API.
        optional - must include client_id if passed.
    :return: An authenticated HUVR client.
    """
    client = HuvrClient(base_url)
    if client_id:
        client.authenticate(client_id, client_secret)
    return client



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class DefectsApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        :param dict params: asset: string
        asset__asset_path_cache__path: string
        asset_type__in: string
        component: string
        component_display: string
        created_on: string
        descendants: string
        geometry_exists: string
        latest: string
        layer: string
        layer__in: string
        limit: integer
        location_code: string
        location_code_display: string
        location_zone: string
        location_zone_display: string
        next_inspection_date: string
        offset: integer
        ordering: string
        priority: string
        profile: string
        profile__in: string
        project: string
        project__name: string
        project_selected_findings: string
        project_type__in: string
        related_to: string
        repair_by: string
        search: string
        severity: string
        severity__in: string
        severity_display: string
        state: string
        type: string
        type_display: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/DefectList'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_defects_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/defects/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/DefectCreate'

        :returns: $ref: '#/components/schemas/DefectCreate'

        https://docs.huvrdata.app/reference/api_defects_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/defects/",
            json=json,
            **kwargs,
        )

    def edit(self, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/schemas/Defect'

        https://docs.huvrdata.app/reference/api_defects_edit
        """
        return self.client.request_json(
            method="post",
            path=f"/api/defects/bulk-edit/",
            json=json,
            **kwargs,
        )

    def filters(self, params=None, **kwargs):
        """
        Returns defect filter object with the asset, asset manufacturer, asset_owner (company), severity, component, location zone, location code, and count

        No query parameters are supported on this endpoint.

        :param dict params: asset: string
        asset__asset_path_cache__path: string
        asset_type__in: string
        component: string
        component_display: string
        created_on: string
        descendants: string
        geometry_exists: string
        latest: string
        layer: string
        layer__in: string
        limit: integer
        location_code: string
        location_code_display: string
        location_zone: string
        location_zone_display: string
        next_inspection_date: string
        offset: integer
        ordering: string
        priority: string
        profile: string
        profile__in: string
        project: string
        project__name: string
        project_selected_findings: string
        project_type__in: string
        related_to: string
        repair_by: string
        search: string
        severity: string
        severity__in: string
        severity_display: string
        state: string
        type: string
        type_display: string

        :returns: $ref: '#/components/schemas/DefectFilter'

        https://docs.huvrdata.app/reference/api_defects_filters
        """
        return self.client.request_json(
            method="get",
            path=f"/api/defects/filters/",
            params=params,
            **kwargs,
        )

    def link(self, json=None, **kwargs):
        """
        Pass a list of defects,
            will link them (via `Defect.newer_defect` field)
            and return list of updated defects,
            in order

        :param dict json: $ref: '#/components/schemas/DefectLink'

        :returns: items:
          $ref: '#/components/schemas/Defect'
        type: array

        https://docs.huvrdata.app/reference/api_defects_link
        """
        return self.client.request_json(
            method="post",
            path=f"/api/defects/link/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        :returns: $ref: '#/components/schemas/Defect'

        https://docs.huvrdata.app/reference/api_defects_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/defects/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/DefectCreate'

        :returns: $ref: '#/components/schemas/Defect'

        https://docs.huvrdata.app/reference/api_defects_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/defects/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/DefectCreate'

        :returns: $ref: '#/components/schemas/DefectCreate'

        https://docs.huvrdata.app/reference/api_defects_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/defects/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        https://docs.huvrdata.app/reference/api_defects_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/defects/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class ChecklistTemplatesApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array of checklist templates.

        :param dict params: categories: string
        in_use: string
        limit: integer
        name: string
        offset: integer
        ordering: string
        schema_version: string
        state: string
        type: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/ChecklistTemplateList'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_checklist-templates_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/checklist-templates/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        View Checklist Templates


        :param dict json: $ref: '#/components/requestBodies/ChecklistTemplate'

        :returns: $ref: '#/components/schemas/ChecklistTemplate'

        https://docs.huvrdata.app/reference/api_checklist-templates_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/checklist-templates/",
            json=json,
            **kwargs,
        )

    def import_template(self, json=None, **kwargs):
        """
        Import a checklist template, this endpoint can simply do the conversion
        from excel to JSON. Or it can create/update the template in a single request.
        The `action` parameter switches between import/convert.
        If the `id` is passed in it will attempt to update the exisiting template.

        :param dict json: $ref: '#/components/requestBodies/ChecklistTemplate'

        :returns: $ref: '#/components/schemas/ChecklistInstance'

        https://docs.huvrdata.app/reference/api_checklist-templates_import_template
        """
        return self.client.request_json(
            method="post",
            path=f"/api/checklist-templates/import-template/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific Checklist Templates
        :params id template ID

        :returns: $ref: '#/components/schemas/ChecklistTemplate'

        https://docs.huvrdata.app/reference/api_checklist-templates_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/checklist-templates/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        View Checklist Templates


        :param dict json: $ref: '#/components/requestBodies/ChecklistTemplate'

        :returns: $ref: '#/components/schemas/ChecklistTemplate'

        https://docs.huvrdata.app/reference/api_checklist-templates_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/checklist-templates/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View Checklist Templates


        :param dict json: $ref: '#/components/requestBodies/ChecklistTemplate'

        :returns: $ref: '#/components/schemas/ChecklistTemplate'

        https://docs.huvrdata.app/reference/api_checklist-templates_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/checklist-templates/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        View Checklist Templates

        https://docs.huvrdata.app/reference/api_checklist-templates_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/checklist-templates/{id}/",
            **kwargs,
        )

    def export_template(self, id, **kwargs):
        """
        Exports existing checklist template in excel format.

        https://docs.huvrdata.app/reference/api_checklist-templates_export_template
        """
        return self.client.request_json(
            method="get",
            path=f"/api/checklist-templates/{id}/export-template/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class UsersApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array users.

        :param dict params: company: string
        date_joined: string
        email: string
        is_active: string
        last_login: string
        limit: integer
        name: string
        offset: integer
        ordering: string
        roles: string
        search: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/User'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_users_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/users/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        User create
        This function is used when creating a new user using the Users tab on the frontend

        :param dict json: $ref: '#/components/requestBodies/UserCreate'

        :returns: $ref: '#/components/schemas/User'

        https://docs.huvrdata.app/reference/api_users_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/users/",
            json=json,
            **kwargs,
        )

    def import_users(self, json=None, **kwargs):
        """
        Pass a list of users addresses,
            sets the same roles/company for all

        :param dict json: $ref: '#/components/schemas/UserImport'

        https://docs.huvrdata.app/reference/api_users_import_users
        """
        return self.client.request_json(
            method="post",
            path=f"/api/users/import/",
            json=json,
            **kwargs,
        )

    def me_read(self, params=None, **kwargs):
        """
        Return current user

        :param dict params: company: string
        date_joined: string
        email: string
        is_active: string
        last_login: string
        limit: integer
        name: string
        offset: integer
        ordering: string
        roles: string
        search: string

        :returns: $ref: '#/components/schemas/UserProfile'

        https://docs.huvrdata.app/reference/api_users_me_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/users/me/",
            params=params,
            **kwargs,
        )

    def me_create(self, json=None, **kwargs):
        """
        Return current user

        :param dict json: $ref: '#/components/schemas/User'

        :returns: $ref: '#/components/schemas/User'

        https://docs.huvrdata.app/reference/api_users_me_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/users/me/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific user
        :params id User ID

        :returns: $ref: '#/components/schemas/User'

        https://docs.huvrdata.app/reference/api_users_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/users/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        User update

        :param dict json: $ref: '#/components/requestBodies/UserCreate'

        :returns: $ref: '#/components/schemas/User'

        https://docs.huvrdata.app/reference/api_users_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/users/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View users


        :param dict json: $ref: '#/components/requestBodies/UserCreate'

        :returns: $ref: '#/components/schemas/UserCreate'

        https://docs.huvrdata.app/reference/api_users_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/users/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        View users

        https://docs.huvrdata.app/reference/api_users_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/users/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class LibraryMediaApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        GET /api/library-media/

        :param dict params: assigned: string
        library: string
        library_name: string
        limit: integer
        name: string
        offset: integer
        ordering: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/LibraryMedia'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_library-media_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/library-media/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        create library media, the actual media object is hosted on GCS.
        For larger files, the preferred method is send the data directly storage.

        Generate a signed url that will allow the client to upload directly to GCS.

        :param dict json: $ref: '#/components/requestBodies/LibraryMediaCreate'

        :returns: $ref: '#/components/schemas/LibraryMedia'

        https://docs.huvrdata.app/reference/api_library-media_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/library-media/",
            json=json,
            **kwargs,
        )

    def summary(self, params=None, **kwargs):
        """
        View library media


        :param dict params: assigned: string
        library: string
        library_name: string
        limit: integer
        name: string
        offset: integer
        ordering: string

        :returns: $ref: '#/components/schemas/LibraryMediaSummary'

        https://docs.huvrdata.app/reference/api_library-media_summary
        """
        return self.client.request_json(
            method="get",
            path=f"/api/library-media/summary/",
            params=params,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific library media
        :params id media ID

        :returns: $ref: '#/components/schemas/LibraryMedia'

        https://docs.huvrdata.app/reference/api_library-media_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/library-media/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        View library media


        :param dict json: $ref: '#/components/requestBodies/LibraryMediaCreate'

        :returns: $ref: '#/components/schemas/LibraryMedia'

        https://docs.huvrdata.app/reference/api_library-media_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/library-media/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View library media


        :param dict json: $ref: '#/components/requestBodies/LibraryMediaCreate'

        :returns: $ref: '#/components/schemas/LibraryMediaCreate'

        https://docs.huvrdata.app/reference/api_library-media_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/library-media/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        View library media

        https://docs.huvrdata.app/reference/api_library-media_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/library-media/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class HeatDataApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array HEAT data

        :param dict params: billet_weight: string
        charge_weight: string
        created_on: string
        crew: string
        grade: string
        grade_type: string
        heat_number: string
        ladle: string
        limit: integer
        offset: integer
        ordering: string
        shift: string
        source__name: string
        tap_start: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/HeatData'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_heat-data_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/heat-data/",
            params=params,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific HEAT data
        :params id HeatData ID

        :returns: $ref: '#/components/schemas/HeatData'

        https://docs.huvrdata.app/reference/api_heat-data_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/heat-data/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class LibrariesApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        GET /api/libraries/

        :param dict params: assigned: string
        limit: integer
        name: string
        offset: integer
        ordering: string
        system: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/Library'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_libraries_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/libraries/",
            params=params,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        View library media


        :returns: $ref: '#/components/schemas/Library'

        https://docs.huvrdata.app/reference/api_libraries_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/libraries/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class SchedulesApiModule(BaseApiModule):
    def events_list(self, params=None, **kwargs):
        """
        Returns an array of schedule events.

        :param dict params: asset: string
        asset__asset_path_cache__path: string
        crew: string
        crew__name: string
        descendants: string
        end: string
        limit: integer
        name: string
        offset: integer
        ordering: string
        plan: string
        quick_date: string
        search: string
        start: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/ScheduleEvent'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_schedule_events_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/schedule/events/",
            params=params,
            **kwargs,
        )

    def events_create(self, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/ScheduleEvent'

        :returns: $ref: '#/components/schemas/ScheduleEvent'

        https://docs.huvrdata.app/reference/api_schedule_events_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/schedule/events/",
            json=json,
            **kwargs,
        )

    def events_read(self, id, **kwargs):
        """
        Return the specific schedule event
        :params id schedule event ID

        :returns: $ref: '#/components/schemas/ScheduleEvent'

        https://docs.huvrdata.app/reference/api_schedule_events_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/schedule/events/{id}/",
            **kwargs,
        )

    def events_update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/ScheduleEvent'

        :returns: $ref: '#/components/schemas/ScheduleEvent'

        https://docs.huvrdata.app/reference/api_schedule_events_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/schedule/events/{id}/",
            json=json,
            **kwargs,
        )

    def events_partial_update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/ScheduleEvent'

        :returns: $ref: '#/components/schemas/ScheduleEvent'

        https://docs.huvrdata.app/reference/api_schedule_events_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/schedule/events/{id}/",
            json=json,
            **kwargs,
        )

    def events_delete(self, id, **kwargs):
        """
        https://docs.huvrdata.app/reference/api_schedule_events_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/schedule/events/{id}/",
            **kwargs,
        )

    def plan_work_list(self, params=None, **kwargs):
        """
        Returns an array of schedule plan work items

        :param dict params: limit: integer
        offset: integer
        ordering: string
        plan: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/SchedulePlanWork'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_schedule_plan-work_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/schedule/plan-work/",
            params=params,
            **kwargs,
        )

    def plan_work_create(self, json=None, **kwargs):
        """
        View schedule work plan


        :param dict json: $ref: '#/components/requestBodies/SchedulePlanWorkCreate'

        :returns: $ref: '#/components/schemas/SchedulePlanWork'

        https://docs.huvrdata.app/reference/api_schedule_plan-work_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/schedule/plan-work/",
            json=json,
            **kwargs,
        )

    def plan_work_read(self, id, **kwargs):
        """
        Return the specific schedule plan work
        :params id schedule plan work ID

        :returns: $ref: '#/components/schemas/SchedulePlanWork'

        https://docs.huvrdata.app/reference/api_schedule_plan-work_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/schedule/plan-work/{id}/",
            **kwargs,
        )

    def plan_work_update(self, id, json=None, **kwargs):
        """
        Schedule Plan update

        :param dict json: $ref: '#/components/requestBodies/SchedulePlanWorkCreate'

        :returns: $ref: '#/components/schemas/SchedulePlan'

        https://docs.huvrdata.app/reference/api_schedule_plan-work_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/schedule/plan-work/{id}/",
            json=json,
            **kwargs,
        )

    def plan_work_partial_update(self, id, json=None, **kwargs):
        """
        View schedule work plan


        :param dict json: $ref: '#/components/requestBodies/SchedulePlanWorkCreate'

        :returns: $ref: '#/components/schemas/SchedulePlanWorkCreate'

        https://docs.huvrdata.app/reference/api_schedule_plan-work_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/schedule/plan-work/{id}/",
            json=json,
            **kwargs,
        )

    def plan_work_delete(self, id, **kwargs):
        """
        View schedule work plan

        https://docs.huvrdata.app/reference/api_schedule_plan-work_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/schedule/plan-work/{id}/",
            **kwargs,
        )

    def plans_list(self, params=None, **kwargs):
        """
        Returns an array of schedule plans

        :param dict params: limit: integer
        name: string
        offset: integer
        ordering: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/SchedulePlan'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_schedule_plans_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/schedule/plans/",
            params=params,
            **kwargs,
        )

    def plans_create(self, json=None, **kwargs):
        """
        View schedule plan


        :param dict json: $ref: '#/components/requestBodies/SchedulePlanCreate'

        :returns: $ref: '#/components/schemas/SchedulePlan'

        https://docs.huvrdata.app/reference/api_schedule_plans_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/schedule/plans/",
            json=json,
            **kwargs,
        )

    def plans_read(self, id, **kwargs):
        """
        Return the specific schedule plan
        :params id schedule plan ID

        :returns: $ref: '#/components/schemas/SchedulePlan'

        https://docs.huvrdata.app/reference/api_schedule_plans_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/schedule/plans/{id}/",
            **kwargs,
        )

    def plans_update(self, id, json=None, **kwargs):
        """
        Schedule Plan update

        :param dict json: $ref: '#/components/requestBodies/SchedulePlanCreate'

        :returns: $ref: '#/components/schemas/SchedulePlan'

        https://docs.huvrdata.app/reference/api_schedule_plans_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/schedule/plans/{id}/",
            json=json,
            **kwargs,
        )

    def plans_partial_update(self, id, json=None, **kwargs):
        """
        View schedule plan


        :param dict json: $ref: '#/components/requestBodies/SchedulePlanCreate'

        :returns: $ref: '#/components/schemas/SchedulePlanCreate'

        https://docs.huvrdata.app/reference/api_schedule_plans_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/schedule/plans/{id}/",
            json=json,
            **kwargs,
        )

    def plans_delete(self, id, **kwargs):
        """
        View schedule plan

        https://docs.huvrdata.app/reference/api_schedule_plans_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/schedule/plans/{id}/",
            **kwargs,
        )

    def plans_generate_events_create(self, id, json=None, **kwargs):
        """
        Generate Events for a SchedulePlan

        :param dict json: $ref: '#/components/requestBodies/SchedulePlan'

        :returns: $ref: '#/components/schemas/SchedulePlanGenerateEvents'

        https://docs.huvrdata.app/reference/api_schedule_plans_generate-events_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/schedule/plans/{id}/generate-events/",
            json=json,
            **kwargs,
        )

    def plans_generate_events_update(self, id, json=None, **kwargs):
        """
        Generate Events for a SchedulePlan

        :param dict json: $ref: '#/components/requestBodies/SchedulePlan'

        :returns: $ref: '#/components/schemas/SchedulePlanGenerateEvents'

        https://docs.huvrdata.app/reference/api_schedule_plans_generate-events_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/schedule/plans/{id}/generate-events/",
            json=json,
            **kwargs,
        )

    def tasks_list(self, params=None, **kwargs):
        """
        Returns an array of schedule task.

        :param dict params: assigned: string
        current: string
        done: string
        event: string
        limit: integer
        offset: integer
        ordering: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/ScheduleTask'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_schedule_tasks_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/schedule/tasks/",
            params=params,
            **kwargs,
        )

    def tasks_read(self, id, **kwargs):
        """
        Return the specific schedule task
        :params id schedule task ID

        :returns: $ref: '#/components/schemas/ScheduleTask'

        https://docs.huvrdata.app/reference/api_schedule_tasks_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/schedule/tasks/{id}/",
            **kwargs,
        )

    def tasks_update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/ScheduleTask'

        :returns: $ref: '#/components/schemas/ScheduleTask'

        https://docs.huvrdata.app/reference/api_schedule_tasks_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/schedule/tasks/{id}/",
            json=json,
            **kwargs,
        )

    def tasks_delete(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/ScheduleTask'

        :returns: $ref: '#/components/schemas/ScheduleTask'

        https://docs.huvrdata.app/reference/api_schedule_tasks_delete
        """
        return self.client.request_json(
            method="post",
            path=f"/api/schedule/tasks/{id}/delete/",
            json=json,
            **kwargs,
        )

    def tasks_reconcile(self, id, json=None, **kwargs):
        """
        Look for work that matches the schedule task.

        :param dict json: $ref: '#/components/requestBodies/ScheduleTask'

        :returns: $ref: '#/components/schemas/ScheduleTaskReconcile'

        https://docs.huvrdata.app/reference/api_schedule_tasks_reconcile
        """
        return self.client.request_json(
            method="post",
            path=f"/api/schedule/tasks/{id}/reconcile/",
            json=json,
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class ChecklistResultLinesApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns a list of ChecklistResultLines, supports various filters

        :param dict params: checklist: string
        checklist__project: string
        checklist__project__name: string
        id: string
        limit: integer
        line_key: string
        notes: string
        offset: integer
        ordering: string
        project: string
        search: string
        section_key: string
        template: string
        template__name: string
        template__version: string
        template_line: string
        template_line__description: string
        template_line__label: string
        template_line__section_description: string
        template_line__section_label: string
        template_line__type: string
        value: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/ChecklistResultLine'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_checklist-result-lines_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/checklist-result-lines/",
            params=params,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return a single ChecklistResultLine by id
            `id` pattern: "{checklist_id}::{section_key}::{line_key}"
            for example: "24::my_section::my_line"

        :returns: $ref: '#/components/schemas/ChecklistResultLine'

        https://docs.huvrdata.app/reference/api_checklist-result-lines_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/checklist-result-lines/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class ProjectsApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array projects.

        :param dict params: asset: string
        asset__asset_path_cache__path: string
        asset__type__in: string
        asset_condition: string
        asset_condition__in: string
        asset_parent__in: string
        asset_search: string
        assigned: string
        completed: string
        created_on: string
        crews__in: string
        crews__name: string
        descendants: string
        end: string
        event: string
        limit: integer
        management_company__in: string
        management_company__name: string
        name: string
        offset: integer
        ordering: string
        parent: string
        priority: string
        related_asset: string
        scope__selected_findings: string
        search: string
        start: string
        status: string
        type: string
        type__in: string
        type__name: string
        updated_on: string
        work_done_on: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/ProjectList'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_projects_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/projects/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        accept a flat object for create, return nested detail object

        :param dict json: $ref: '#/components/requestBodies/ProjectCreate'

        :returns: $ref: '#/components/schemas/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/projects/",
            json=json,
            **kwargs,
        )

    def delete(self, json=None, **kwargs):
        """
        View projects


        :param dict json: $ref: '#/components/requestBodies/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_delete
        """
        return self.client.request_json(
            method="post",
            path=f"/api/projects/bulk-delete/",
            json=json,
            **kwargs,
        )

    def edit(self, json=None, **kwargs):
        """
        View projects


        :param dict json: $ref: '#/components/requestBodies/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_edit
        """
        return self.client.request_json(
            method="post",
            path=f"/api/projects/bulk-edit/",
            json=json,
            **kwargs,
        )

    def bulk_share(self, json=None, **kwargs):
        """
        allow for bulk assignment/unassignment of multiple users to multiple projects

        :param dict json: $ref: '#/components/schemas/ProjectBulkShare'

        :returns: $ref: '#/components/schemas/ProjectListDetailed'

        https://docs.huvrdata.app/reference/api_projects_bulk_share
        """
        return self.client.request_json(
            method="post",
            path=f"/api/projects/bulk-share/",
            json=json,
            **kwargs,
        )

    def counts_by_status(self, params=None, **kwargs):
        """
        View projects


        :param dict params: asset: string
        asset__asset_path_cache__path: string
        asset__type__in: string
        asset_condition: string
        asset_condition__in: string
        asset_parent__in: string
        asset_search: string
        assigned: string
        completed: string
        created_on: string
        crews__in: string
        crews__name: string
        descendants: string
        end: string
        event: string
        limit: integer
        management_company__in: string
        management_company__name: string
        name: string
        offset: integer
        ordering: string
        parent: string
        priority: string
        related_asset: string
        scope__selected_findings: string
        search: string
        start: string
        status: string
        type: string
        type__in: string
        type__name: string
        updated_on: string
        work_done_on: string

        :returns: $ref: '#/components/schemas/ProjectCountsByStatus'

        https://docs.huvrdata.app/reference/api_projects_counts_by_status
        """
        return self.client.request_json(
            method="get",
            path=f"/api/projects/counts-by-status/",
            params=params,
            **kwargs,
        )

    def list_detailed(self, params=None, **kwargs):
        """
        Shows a detailed list or projects (slow).

        :param dict params: asset: string
        asset__asset_path_cache__path: string
        asset__type__in: string
        asset_condition: string
        asset_condition__in: string
        asset_parent__in: string
        asset_search: string
        assigned: string
        completed: string
        created_on: string
        crews__in: string
        crews__name: string
        descendants: string
        end: string
        event: string
        limit: integer
        management_company__in: string
        management_company__name: string
        name: string
        offset: integer
        ordering: string
        parent: string
        priority: string
        related_asset: string
        scope__selected_findings: string
        search: string
        start: string
        status: string
        type: string
        type__in: string
        type__name: string
        updated_on: string
        work_done_on: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/ProjectDetail'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_projects_list_detailed
        """
        return self.client.request_json(
            method="get",
            path=f"/api/projects/detailed/",
            params=params,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific project
        :params id Project ID

        :returns: $ref: '#/components/schemas/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/projects/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        Project update. work_done_on is ignored if 'historical_project' is true

        :param dict json: $ref: '#/components/requestBodies/ProjectCreate'

        :returns: $ref: '#/components/schemas/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/projects/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View projects


        :param dict json: $ref: '#/components/requestBodies/ProjectCreate'

        :returns: $ref: '#/components/schemas/ProjectCreate'

        https://docs.huvrdata.app/reference/api_projects_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/projects/{id}/",
            json=json,
            **kwargs,
        )

    def delete_alt(self, id, **kwargs):
        """
        View projects

        https://docs.huvrdata.app/reference/api_projects_delete_alt
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/projects/{id}/",
            **kwargs,
        )

    def asset_condition_read(self, id, **kwargs):
        """
        Set the project asset condition, allow retrival of the project asset condition history

        :returns: items:
          $ref: '#/components/schemas/AssetConditionHistoryInline'
        type: array

        https://docs.huvrdata.app/reference/api_projects_asset-condition_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/projects/{id}/asset-condition/",
            **kwargs,
        )

    def asset_condition_create(self, id, json=None, **kwargs):
        """
        Set the project asset condition, allow retrival of the project asset condition history

        :param dict json: $ref: '#/components/schemas/AssetConditionChange'

        :returns: $ref: '#/components/schemas/AssetConditionHistoryInline'

        https://docs.huvrdata.app/reference/api_projects_asset-condition_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/projects/{id}/asset-condition/",
            json=json,
            **kwargs,
        )

    def asset_condition_update(self, id, json=None, **kwargs):
        """
        Set the project asset condition, allow retrival of the project asset condition history

        :param dict json: $ref: '#/components/requestBodies/ProjectDetail'

        :returns: $ref: '#/components/schemas/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_asset-condition_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/projects/{id}/asset-condition/",
            json=json,
            **kwargs,
        )

    def export(self, id, **kwargs):
        """
        Exports existing project in excel format.
        This is a simple helper API endpoint that is run by developers only
        as this process will probably (depending on data) outgrow an inline request.

        https://docs.huvrdata.app/reference/api_projects_export
        """
        return self.client.request_json(
            method="get",
            path=f"/api/projects/{id}/export/",
            **kwargs,
        )

    def location_summary(self, id, **kwargs):
        """
        Location summary of the findings/defects for a given project

        :returns: $ref: '#/components/schemas/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_location_summary
        """
        return self.client.request_json(
            method="get",
            path=f"/api/projects/{id}/location-summary/",
            **kwargs,
        )

    def status_read(self, id, **kwargs):
        """
        Set the project status, allow retrieval of the project status history

        :returns: items:
          $ref: '#/components/schemas/ProjectStatus'
        type: array

        https://docs.huvrdata.app/reference/api_projects_status_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/projects/{id}/status/",
            **kwargs,
        )

    def status_create(self, id, json=None, **kwargs):
        """
        Set the project status, allow retrieval of the project status history

        :param dict json: $ref: '#/components/requestBodies/ProjectStatusEdit'

        :returns: $ref: '#/components/schemas/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_status_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/projects/{id}/status/",
            json=json,
            **kwargs,
        )

    def status_update(self, id, json=None, **kwargs):
        """
        Set the project status, allow retrieval of the project status history

        :param dict json: $ref: '#/components/requestBodies/ProjectStatusEdit'

        :returns: $ref: '#/components/schemas/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_status_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/projects/{id}/status/",
            json=json,
            **kwargs,
        )

    def watch(self, id, json=None, **kwargs):
        """
        Set the project watchers, allow retrival of the project watchers

        :param dict json: $ref: '#/components/schemas/ProjectShare'

        :returns: $ref: '#/components/schemas/ProjectDetail'

        https://docs.huvrdata.app/reference/api_projects_watch
        """
        return self.client.request_json(
            method="post",
            path=f"/api/projects/{id}/watch/",
            json=json,
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class AssetsApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array of assets.

        :param dict params: app_key: string
        asset_condition: string
        asset_condition__in: string
        asset_id: string
        asset_path: string
        asset_path_cache__path: string
        asset_path_search: string
        asset_type__in: string
        created_on: string
        deactivated_on: string
        descendants: string
        description: string
        external_id: string
        geo_point__bounding_box: string
        is_active: string
        labels: string
        limit: integer
        manufacturer: string
        model: string
        name: string
        no_parent: string
        offset: integer
        ordering: string
        owner: string
        owner__in: string
        owner__name: string
        parent: string
        parent__in: string
        related: string
        search: string
        serial_number: string
        type: string
        type__name: string
        updated_on: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/AssetDetail'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_assets_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/assets/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        accept a flat object for create, return nested detail object

        :param dict json: $ref: '#/components/schemas/AssetCreate'

        :returns: $ref: '#/components/schemas/AssetDetail'

        https://docs.huvrdata.app/reference/api_assets_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/assets/",
            json=json,
            **kwargs,
        )

    def asset_condition_map(self, params=None, **kwargs):
        """
        Asset endpoint


        :param dict params: app_key: string
        asset_condition: string
        asset_condition__in: string
        asset_id: string
        asset_path: string
        asset_path_cache__path: string
        asset_path_search: string
        asset_type__in: string
        created_on: string
        deactivated_on: string
        descendants: string
        description: string
        external_id: string
        geo_point__bounding_box: string
        is_active: string
        labels: string
        limit: integer
        manufacturer: string
        model: string
        name: string
        no_parent: string
        offset: integer
        ordering: string
        owner: string
        owner__in: string
        owner__name: string
        parent: string
        parent__in: string
        related: string
        search: string
        serial_number: string
        type: string
        type__name: string
        updated_on: string

        :returns: items:
          $ref: '#/components/schemas/AssetConditionMap'
        type: array

        https://docs.huvrdata.app/reference/api_assets_asset_condition_map
        """
        return self.client.request_json(
            method="get",
            path=f"/api/assets/asset-condition-map/",
            params=params,
            **kwargs,
        )

    def filters(self, params=None, **kwargs):
        """
        No query parameters are supported on this endpoint.

        :param dict params: app_key: string
        asset_condition: string
        asset_condition__in: string
        asset_id: string
        asset_path: string
        asset_path_cache__path: string
        asset_path_search: string
        asset_type__in: string
        created_on: string
        deactivated_on: string
        descendants: string
        description: string
        external_id: string
        geo_point__bounding_box: string
        is_active: string
        labels: string
        limit: integer
        manufacturer: string
        model: string
        name: string
        no_parent: string
        offset: integer
        ordering: string
        owner: string
        owner__in: string
        owner__name: string
        parent: string
        parent__in: string
        related: string
        search: string
        serial_number: string
        type: string
        type__name: string
        updated_on: string

        :returns: $ref: '#/components/schemas/AssetFilter'

        https://docs.huvrdata.app/reference/api_assets_filters
        """
        return self.client.request_json(
            method="get",
            path=f"/api/assets/filters/",
            params=params,
            **kwargs,
        )

    def tree(self, params=None, **kwargs):
        """
        Asset endpoint


        :param dict params: app_key: string
        asset_condition: string
        asset_condition__in: string
        asset_id: string
        asset_path: string
        asset_path_cache__path: string
        asset_path_search: string
        asset_type__in: string
        created_on: string
        deactivated_on: string
        descendants: string
        description: string
        external_id: string
        geo_point__bounding_box: string
        is_active: string
        labels: string
        limit: integer
        manufacturer: string
        model: string
        name: string
        no_parent: string
        offset: integer
        ordering: string
        owner: string
        owner__in: string
        owner__name: string
        parent: string
        parent__in: string
        related: string
        search: string
        serial_number: string
        type: string
        type__name: string
        updated_on: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/AssetDetail'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_assets_tree
        """
        return self.client.request_json(
            method="get",
            path=f"/api/assets/tree/",
            params=params,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific asset
        :params id asset ID

        :returns: $ref: '#/components/schemas/AssetDetail'

        https://docs.huvrdata.app/reference/api_assets_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/assets/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        Asset update. Asset type and asset path are ignored on updates

        :param dict json: $ref: '#/components/requestBodies/AssetUpdate'

        :returns: $ref: '#/components/schemas/AssetDetail'

        https://docs.huvrdata.app/reference/api_assets_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/assets/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        Asset endpoint


        :param dict json: $ref: '#/components/requestBodies/AssetUpdate'

        :returns: $ref: '#/components/schemas/AssetUpdate'

        https://docs.huvrdata.app/reference/api_assets_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/assets/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        Asset endpoint

        https://docs.huvrdata.app/reference/api_assets_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/assets/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class CrewsApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array of Crew objectss

        :param dict params: company: string
        is_active: string
        limit: integer
        name: string
        offset: integer
        ordering: string
        user: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/CrewDetail'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_crews_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/crews/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        accept a flat object for create, return nested detail object

        :param dict json: $ref: '#/components/schemas/CrewCreate'

        :returns: $ref: '#/components/schemas/CrewDetail'

        https://docs.huvrdata.app/reference/api_crews_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/crews/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific Crew
        :params id crew ID

        :returns: $ref: '#/components/schemas/CrewDetail'

        https://docs.huvrdata.app/reference/api_crews_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/crews/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        Crew update. Company is ignored on updates

        :param dict json: $ref: '#/components/requestBodies/CrewUpdate'

        :returns: $ref: '#/components/schemas/CrewDetail'

        https://docs.huvrdata.app/reference/api_crews_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/crews/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        Crew endpoint


        :param dict json: $ref: '#/components/requestBodies/CrewUpdate'

        :returns: $ref: '#/components/schemas/CrewUpdate'

        https://docs.huvrdata.app/reference/api_crews_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/crews/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        Crew endpoint

        https://docs.huvrdata.app/reference/api_crews_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/crews/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class PagesApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array Pages.

        :param dict params: limit: integer
        offset: integer
        ordering: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/PageList'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_pages_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/pages/",
            params=params,
            **kwargs,
        )

    def retrieve_by_path(self, path, params=None, **kwargs):
        """
        The path will have to be url-encoded when coming in.

        :param dict params: limit: integer
        offset: integer
        ordering: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/PageDetail'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_pages_retrieve_by_path
        """
        return self.client.request_json(
            method="get",
            path=f"/api/pages/by-path/{path}/",
            params=params,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific Page
        :params id Page ID

        :returns: $ref: '#/components/schemas/PageDetail'

        https://docs.huvrdata.app/reference/api_pages_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/pages/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class InspectionMediaApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        :param dict params: captured_on: string
        checklist: string
        component_display: string
        created_by_me: string
        created_on: string
        defect: string
        document_category: string
        file: string
        geo_point__bounding_box: string
        hidden: string
        limit: integer
        location_code_display: string
        location_zone_display: string
        name: string
        offset: integer
        ordering: string
        priority: string
        project: string
        recent: string
        related: string
        search: string
        size: string
        size_max: string
        size_min: string
        state: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/InspectionMedia'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_inspection-media_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/inspection-media/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        create inspection media, the actual media object is hosted on GCS.
        For larger files, the preferred method is send the data directly storage.

        Generate a signed url that will allow the client to upload directly to GCS.

        :param dict json: $ref: '#/components/schemas/InspectionMediaCreate'

        :returns: $ref: '#/components/schemas/InspectionMedia'

        https://docs.huvrdata.app/reference/api_inspection-media_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/inspection-media/",
            json=json,
            **kwargs,
        )

    def delete(self, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/InspectionMedia'

        https://docs.huvrdata.app/reference/api_inspection-media_delete
        """
        return self.client.request_json(
            method="post",
            path=f"/api/inspection-media/bulk-delete/",
            json=json,
            **kwargs,
        )

    def edit(self, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/InspectionMedia'

        https://docs.huvrdata.app/reference/api_inspection-media_edit
        """
        return self.client.request_json(
            method="post",
            path=f"/api/inspection-media/bulk-edit/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        :returns: $ref: '#/components/schemas/InspectionMedia'

        https://docs.huvrdata.app/reference/api_inspection-media_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/inspection-media/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/InspectionMediaUpdate'

        :returns: $ref: '#/components/schemas/InspectionMedia'

        https://docs.huvrdata.app/reference/api_inspection-media_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/inspection-media/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/InspectionMediaUpdate'

        :returns: $ref: '#/components/schemas/InspectionMediaUpdate'

        https://docs.huvrdata.app/reference/api_inspection-media_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/inspection-media/{id}/",
            json=json,
            **kwargs,
        )

    def delete_alt(self, id, **kwargs):
        """
        https://docs.huvrdata.app/reference/api_inspection-media_delete_alt
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/inspection-media/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class AuthApiModule(BaseApiModule):
    def obtain_access_token_create(self, json=None, **kwargs):
        """
        NOTE - we're using `client_id` and `client_secret`
            standard naming for "OAuth Client Credentials Flow"
            they map internally to service user's `email` and `password`
            https://auth0.com/docs/get-started/authentication-and-authorization-flow/client-credentials-flow

        Return a short-lived Token used for subsequent requests

        :param dict json: $ref: '#/components/schemas/ObtainAccessTokenRequest'

        :returns: $ref: '#/components/schemas/ObtainAccessTokenResponse'

        https://docs.huvrdata.app/reference/api_auth_obtain-access-token_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/auth/obtain-access-token/",
            json=json,
            **kwargs,
        )

    def session_login_create(self, **kwargs):
        """
        Verify JWT from client
         - sets `auth` cookie on response (used for _firebase_ auth)
         - sets `sessionid` cookie on response (used for _django_ auth)

        https://docs.huvrdata.app/reference/api_auth_session-login_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/auth/session-login/",
            **kwargs,
        )

    def session_logout_create(self, **kwargs):
        """
        Removes session cookie

        https://docs.huvrdata.app/reference/api_auth_session-logout_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/auth/session-logout/",
            **kwargs,
        )



class BaseApiModule:
    """
    A base class for all API modules.
    Gives access to the client and provides
    a common interface for all modules.
    """

    def __init__(self, client):
        self.client = client



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class LocationLayerProfilesApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array of LocationLayerProfile.

        :param dict params: limit: integer
        offset: integer
        ordering: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/LocationLayerProfile'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_location-layer-profiles_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/location-layer-profiles/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        View LocationLayerProfile


        :param dict json: $ref: '#/components/requestBodies/LocationLayerProfile'

        :returns: $ref: '#/components/schemas/LocationLayerProfile'

        https://docs.huvrdata.app/reference/api_location-layer-profiles_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/location-layer-profiles/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific LocationLayerProfile
        :params id

        :returns: $ref: '#/components/schemas/LocationLayerProfile'

        https://docs.huvrdata.app/reference/api_location-layer-profiles_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/location-layer-profiles/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        View LocationLayerProfile


        :param dict json: $ref: '#/components/requestBodies/LocationLayerProfile'

        :returns: $ref: '#/components/schemas/LocationLayerProfile'

        https://docs.huvrdata.app/reference/api_location-layer-profiles_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/location-layer-profiles/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View LocationLayerProfile


        :param dict json: $ref: '#/components/requestBodies/LocationLayerProfile'

        :returns: $ref: '#/components/schemas/LocationLayerProfile'

        https://docs.huvrdata.app/reference/api_location-layer-profiles_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/location-layer-profiles/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        View LocationLayerProfile

        https://docs.huvrdata.app/reference/api_location-layer-profiles_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/location-layer-profiles/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class ChecklistsApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array of checklist instances.

        :param dict params: asset: string
        asset__asset_path_cache__path: string
        asset__id: string
        created_by: string
        created_by_me: string
        created_on: string
        descendants: string
        labels: string
        limit: integer
        offset: integer
        ordering: string
        project: string
        recent: string
        search: string
        tasks: string
        template: string
        template__categories: string
        template__id__in: string
        template__name: string
        template__type: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/ChecklistInstanceList'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_checklists_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/checklists/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        View Checklist Instances


        :param dict json: $ref: '#/components/schemas/ChecklistInstanceCreate'

        :returns: $ref: '#/components/schemas/ChecklistInstance'

        https://docs.huvrdata.app/reference/api_checklists_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/checklists/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific Checklist Instances
        :params id Instance ID

        :returns: $ref: '#/components/schemas/ChecklistInstance'

        https://docs.huvrdata.app/reference/api_checklists_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/checklists/{id}/",
            **kwargs,
        )

    def edit(self, id, json=None, **kwargs):
        """
        edit a checklist instance

        :param dict json: $ref: '#/components/schemas/ChecklistEditInline'

        :returns: $ref: '#/components/schemas/ChecklistInstance'

        https://docs.huvrdata.app/reference/api_checklists_edit
        """
        return self.client.request_json(
            method="post",
            path=f"/api/checklists/{id}/edit/",
            json=json,
            **kwargs,
        )

    def revisions_read(self, id, **kwargs):
        """
        Set revisions object

        :returns: items:
          $ref: '#/components/schemas/ChecklistRevisionEdit'
        type: array

        https://docs.huvrdata.app/reference/api_checklists_revisions_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/checklists/{id}/revisions/",
            **kwargs,
        )

    def revisions_partial_update(self, id, json=None, **kwargs):
        """
        Set revisions object

        :param dict json: $ref: '#/components/schemas/ChecklistEdit'

        :returns: $ref: '#/components/schemas/ChecklistInstance'

        https://docs.huvrdata.app/reference/api_checklists_revisions_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/checklists/{id}/revisions/",
            json=json,
            **kwargs,
        )

    def overlays_create(self, id, json=None, **kwargs):
        """
        add or edit a overlay on a media object

        :param dict json: $ref: '#/components/requestBodies/InspectionMediaOverlayCreate'

        :returns: $ref: '#/components/schemas/InspectionMedia'

        https://docs.huvrdata.app/reference/api_inspection-media_overlays_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/inspection-media/{id}/overlays/",
            json=json,
            **kwargs,
        )

    def overlays_partial_update(self, id, json=None, **kwargs):
        """
        add or edit a overlay on a media object

        :param dict json: $ref: '#/components/requestBodies/InspectionMedia'

        :returns: $ref: '#/components/schemas/InspectionMedia'

        https://docs.huvrdata.app/reference/api_inspection-media_overlays_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/inspection-media/{id}/overlays/",
            json=json,
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class RecommendedWorkPlansApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        return an array of RecommendedWorkPlan

        :param dict params: assessment_revision__assessment__asset: string
        assessment_revision__assessment__asset__asset_path_cache__path: string
        asset__descendants: string
        asset__type__in: string
        description__icontains: string
        due: string
        limit: integer
        name: string
        name__icontains: string
        offset: integer
        ordering: string
        risk_score__display: string
        risk_score__level: string
        status__in: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/RecommendedWorkPlanDetail'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_recommended-work-plans_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/recommended-work-plans/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        :param dict json: $ref: '#/components/requestBodies/RecommendedWorkPlanDetail'

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/recommended-work-plans/",
            json=json,
            **kwargs,
        )

    def bulk_edit(self, json=None, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        :param dict json: $ref: '#/components/requestBodies/RecommendedWorkPlanDetail'

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_bulk_edit
        """
        return self.client.request_json(
            method="post",
            path=f"/api/recommended-work-plans/bulk-edit/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific RecommendedWorkPlan

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/recommended-work-plans/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        :param dict json: $ref: '#/components/requestBodies/RecommendedWorkPlanDetail'

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/recommended-work-plans/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        :param dict json: $ref: '#/components/requestBodies/RecommendedWorkPlanDetail'

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/recommended-work-plans/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        https://docs.huvrdata.app/reference/api_recommended-work-plans_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/recommended-work-plans/{id}/",
            **kwargs,
        )



from .__version__ import __title__, __description__, __url__  # noqa
from .__version__ import __author__, __author_email__, __license__  # noqa
from .__version__ import __copyright__  # noqa


from .client import HuvrClient, get_huvr_client


__all__ = [
    "HuvrClient",
    "get_huvr_client",
]



import requests


class HuvrApiError(requests.RequestException):
    """
    Base exception for HUVR API errors.
    """

    pass


class HuvrApiRequestError(HuvrApiError):
    """
    Exception for HUVR API request errors.
    """

    pass


class HuvrApiAuthError(HuvrApiError):
    """
    Exception for HUVR API authentication errors.
    """

    pass


class HuvrJSONResponseError(HuvrApiError):
    """
    Exception for HUVR API JSON response errors.
    """

    pass



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class CmlsApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        :param dict params: access_display: string
        app_key: string
        asset: string
        asset__asset_path_cache__path: string
        component_display: string
        created_on: string
        descendants: string
        external_id: string
        is_active: string
        limit: integer
        location_code_display: string
        measurements_summary__base: string
        measurements_summary__last: string
        measurements_summary__near: string
        name: string
        offset: integer
        ordering: string
        search: string
        type: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/CML'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_cmls_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/cmls/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        create CML

        :param dict json: $ref: '#/components/requestBodies/CMLCreate'

        :returns: $ref: '#/components/schemas/CML'

        https://docs.huvrdata.app/reference/api_cmls_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/cmls/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        :returns: $ref: '#/components/schemas/CML'

        https://docs.huvrdata.app/reference/api_cmls_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/cmls/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/CMLCreate'

        :returns: $ref: '#/components/schemas/CML'

        https://docs.huvrdata.app/reference/api_cmls_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/cmls/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        :param dict json: $ref: '#/components/requestBodies/CMLCreate'

        :returns: $ref: '#/components/schemas/CMLCreate'

        https://docs.huvrdata.app/reference/api_cmls_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/cmls/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        https://docs.huvrdata.app/reference/api_cmls_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/cmls/{id}/",
            **kwargs,
        )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages
import os


try:
    version = os.environ["GH_RELEASE_TAG"]
except KeyError as e:
    print("GH_RELEASE_TAG not set, (Hint - did you create a release on GitHub?)")
    raise e


with open("README.md") as readme_file:
    readme = readme_file.read()

requirements = ["requests"]

setup(
    author="HUVRdata",
    author_email="api@huvrdata.com",
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
    ],
    description="A python client for the HUVRdata API.",
    install_requires=requirements,
    long_description=readme,
    long_description_content_type="text/markdown",
    keywords="huvr_client",
    name="huvr_client",
    packages=find_packages(include=["huvr_client", "huvr_client.api"]),
    test_suite="tests",
    url="https://github.com/huvrdata/huvr-client",
    version=version,
)



__title__ = "huvr_client"
__description__ = "Python Client for HUVRdata"
__url__ = "https://www.huvrdata.com"
__author__ = "HUVRdata"
__author_email__ = "api@huvrdata.com"
__license__ = "BSD 2.0"
__copyright__ = "Copyright 2023 HUVRdata LLC"



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class CompaniesApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array companies.

        :param dict params: is_active: string
        limit: integer
        name: string
        offset: integer
        ordering: string
        role: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/Company'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_companies_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/companies/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        View companies


        :param dict json: $ref: '#/components/requestBodies/Company'

        :returns: $ref: '#/components/schemas/Company'

        https://docs.huvrdata.app/reference/api_companies_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/companies/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific company
        :params id Company ID

        :returns: $ref: '#/components/schemas/Company'

        https://docs.huvrdata.app/reference/api_companies_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/companies/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        company update

        :param dict json: $ref: '#/components/requestBodies/Company'

        :returns: $ref: '#/components/schemas/Company'

        https://docs.huvrdata.app/reference/api_companies_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/companies/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View companies


        :param dict json: $ref: '#/components/requestBodies/Company'

        :returns: $ref: '#/components/schemas/Company'

        https://docs.huvrdata.app/reference/api_companies_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/companies/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        View companies

        https://docs.huvrdata.app/reference/api_companies_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/companies/{id}/",
            **kwargs,
        )



"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class ObservationsSummaryApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        The Observations API returns a summary/counts of checklist instance data
        based on the grouping of the checklist template. The templates are
        typically filtered by a category. (i.e. Safety)



        :param dict params: asset: string
        asset__asset_path_cache__path: string
        asset__id: string
        created_by: string
        created_by_me: string
        created_on: string
        descendants: string
        labels: string
        limit: integer
        offset: integer
        ordering: string
        project: string
        recent: string
        search: string
        tasks: string
        template: string
        template__categories: string
        template__id__in: string
        template__name: string
        template__type: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/ChecklistSummary'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_observations-summary_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/observations-summary/",
            params=params,
            **kwargs,
        )
